@@ -7,7 +7,7 @@ BEGIN { require Fennec::Runner }
 use Fennec::Test;
 use Fennec::Util qw/inject_sub require_module verbose_message/;
 use Carp qw/croak carp/;
-our $VERSION = '2.010';
+our $VERSION = '2.011';
 
 sub defaults {
     (
@@ -19,10 +19,11 @@ sub defaults {
             'Mock::Quick',
             'Child',
         ],
-        parallel     => 3,
+        parallel     => $ENV{'FENNEC_PARALLEL'} || 3,
         runner_class => 'Fennec::Runner',
         with_tests   => [],
         Child        => ['child'],
+        debug        => $ENV{'FENNEC_DEBUG'} || 0,
     );
 }
 
@@ -305,7 +306,7 @@ t/some_test.t:
 =head2 DECLARE SYNTAX
 
 B<Note:> In order to use this you B<MUST> install L<Fennec::Declare> which is a
-seperate distribution on cpan. This module is seperate because it uses the
+separate distribution on cpan. This module is separate because it uses the
 controversial L<Devel::Declare> module.
 
 t/some_test.t:
@@ -448,7 +449,7 @@ I<Provided by Mock::Quick>
 
 =head1 DEFAULT IMPORTED MODULES
 
-B<Note:> These can be overriden either on import, or by subclassing Fennec.
+B<Note:> These can be overridden either on import, or by subclassing Fennec.
 
 =over 4
 
@@ -517,6 +518,34 @@ class() subroutine is defined and returns the name.
 How many test blocks can be run in parallel. Default is 3. Set to 1 to fork for
 each test, but only run one at a time. Set to 0 to prevent forking.
 
+You can also set this using the C<$FENNEC_PARALLEL> environment variable.
+
+=item debug => 1
+
+Enable tracking debugging information. At the end of the Fennec run it will
+present you with a CSV temp file. This file lists all blocks that are run, and
+mocks that are made in sequence from top to bottom. The actions are split into
+columns by PID. This is usedul when debugging potential race-conditions when
+using parallel testing.
+
+Example:
+
+    26150,26151,26152,26153,26154
+    0 26150 BLOCK 54->78 child: outer_wrap, , , , , 
+     ,1 26151 BLOCK 47->52 test: class_store, , , , 
+    0 26150 MOCK Foo => (outer), , , , , 
+    0 26150 BLOCK 58->61 before_all: ba, , , , , 
+     , ,2 26152 MOCK Foo => (outer), , , 
+     , ,2 26152 BLOCK 63->66 before_each: be, , , 
+     , ,2 26152 BLOCK 68->72 test: the_check, , , 
+     , , ,3 26153 BLOCK 16->31 test: object, , 
+     , , , ,4 26154 BLOCK 33->45 test: class, 
+
+You can use this in a spreadsheet program, or use this command to look at it in
+a more friendly way.
+
+    column -s, -t < '/path/to/tempfile' | less -#2 -S
+
 =item collector_class => 'Fennec::Collector::TB::TempFiles'
 
 Specify which collector to use. Defaults to a Test::Builder based collector
@@ -562,7 +591,7 @@ common to multiple test files.
 
 =item seed => '...'
 
-Set the random seed to be used. Defaults to current date, can be overriden by
+Set the random seed to be used. Defaults to current date, can be overridden by
 the FENNEC_SEED environment variable.
 
 =item debug => $BOOL
@@ -716,6 +745,7 @@ Examples can be the best form of documentation.
 =head3 VANILLA SYNTAX
 
 t/simple.t
+
     use strict;
     use warnings;
 
@@ -744,6 +774,7 @@ t/simple.t
 =head3 DECLARE SYNTAX
 
 t/simple.t
+
     use strict;
     use warnings;
 
@@ -782,6 +813,7 @@ in total 8 tests will be run.
 =head3 VANILLA
 
 sample.t:
+
     use strict;
     use warnings;
 
@@ -806,6 +838,7 @@ sample.t:
 =head3 OBJECT ORIENTED
 
 sample.t
+
     use strict;
     use warnings;
 
@@ -841,6 +874,7 @@ sample.t
 B<Note:> no need to shift $self, it is done for you!
 
 sample.t
+
     use strict;
     use warnings;
 
@@ -996,6 +1030,7 @@ argument to Fennec. This matters because you can subclass Fennec to always
 include this library.
 
 t/test.t
+
     use strict;
     use warnings;
     use Fennec;
@@ -1005,6 +1040,7 @@ t/test.t
     done_testing;
 
 lib/Some/Test/Lib.pm
+
     package Some::Test::Lib;
     use Test::Workflow;
     use Test::More;
@@ -1080,6 +1116,7 @@ for the main process to demonstrate that after_all really does come last.
     7253 after_all runs last.
 
 sample.t
+
     use strict;
     use warnings;
 
